@@ -7,6 +7,8 @@ DEVICE_TYPE_PURE_COOL_LINK_DESK = "469"
 DEVICE_TYPE_PURE_COOL = "438"
 DEVICE_TYPE_PURE_COOL_DESK = "520"
 DEVICE_TYPE_PURE_HUMIDITY_COOL = "358"
+DEVICE_TYPE_PURE_HOT_COOL_LINK = "455"
+DEVICE_TYPE_PURE_HOT_COOL = "527"
 
 DEVICE_TYPE_NAMES = {
     DEVICE_TYPE_360_EYE: "360 Eye™ robot vacuum",
