@@ -379,3 +379,44 @@ class DysonFanDevice(DysonDevice):
     def reset_filter(self) -> None:
         """Reset filter life."""
         self._set_configuration(rstf="RSTF")
+
+
+class DysonHeatingDevice(DysonFanDevice):
+    """Dyson heating fan device."""
+
+    @property
+    def focus_mode(self) -> bool:
+        """Return if fan focus mode is on."""
+        return self._get_field_value(self._status, "ffoc") == "ON"
+
+    @property
+    def heat_target(self) -> float:
+        """Return heat target in kelvin."""
+        return int(self._get_field_value(self._status, "hmax")) / 10
+
+    @property
+    def heat_mode_is_on(self) -> bool:
+        """Return if heat mode is set to on."""
+        return self._get_field_value(self._status, "hmod") == "HEAT"
+
+    @property
+    def heat_status_is_on(self) -> bool:
+        """Return if the device is currently heating."""
+        return self._get_field_value(self._status, "hsta") == "HEAT"
+
+    def set_heat_target(self, heat_target: float) -> None:
+        """Set heat target in kelvin."""
+        if not 274 <= heat_target <= 310:
+            raise ValueError("Heat target must be between 274 and 310 kelvin")
+        self._set_configuration(
+            hmod="HEAT",
+            hmax=f"{round(heat_target * 10):04d}",
+        )
+
+    def enable_heat_mode(self) -> None:
+        """Enable heat mode."""
+        self._set_configuration(hmod="HEAT")
+
+    def disable_heat_mode(self) -> None:
+        """Disable heat mode."""
+        self._set_configuration(hmod="OFF")
